This function returns a list of following relation variables below.
follValis a following-relation value s.t. if follVal is positive, then Y follows X. If follVal is negative, then X follows Y.
Otherwise, if follVal is zero, there is no following relation between X,Y.
nXis a time series that is rearranged from X by applying the lags optIndexVec in order to imitate Y.
optDelayis the optimal time delay inferred by cross-correlation of X,Y. It is positive if Y is simply just a time-shift of X (e.g. Y[t]=X[t-optDelay]).
optCoris the optimal correlation of Y[t]=X[t-optDelay] for all t.
optIndexVecis a time series of optimal warping-path from DTW that is corrected by cross correlation.
It is approximately that Y[t]=X[t-optIndexVec[t]]).
VLvalis a percentage of elements in optIndexVec that is not equal to optDelay.
ccfoutis an output object of ccf function.